import docx2txt
from sklearn.feature_extraction.text import CountVectorizer
from sklearn.metrics.pairwise import cosine_similarity

def resume_job_desc_match(resume,job_desc):
    job_desc = docx2txt.process(job_desc)
    resume = docx2txt.process(resume)
    content = [resume,job_desc]
    cv = CountVectorizer()
    matrix = cv.fit_transform(content)
    similarity_matrix = cosine_similarity(matrix)
    match_percentage = similarity_matrix[0][1]*100
    return f"{round(match_percentage, 2)}%"




from setuptools import setup, find_packages

setup(
    name='resume-matcher',
    version='0.2',
    description='A Python library for matching resumes with job descriptions',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'resume-matcher=resume_matcher.matching:main',
        ],
    },
    install_requires=[
        'docx2txt',
        'scikit-learn'
    ],
)